@@ -1,7 +1,7 @@
 var NAVTREE =
 [
   [ "LibOFX", "index.html", [
-    [ "LibOFX developer's manual", "index.html", null ],
+    [ "tree.hh", "index.html", null ],
     [ "Data Structures", "annotated.html", [
       [ "cmdline_parser_params", "structcmdline__parser__params.html", null ],
       [ "ErrorMsg", "structErrorMsg.html", null ],
@@ -11,7 +11,6 @@ var NAVTREE =
       [ "tree< T, tree_node_allocator >::iterator_base_less", "classtree_1_1iterator__base__less.html", null ],
       [ "LibofxContext", "classLibofxContext.html", null ],
       [ "LibofxFileFormatInfo", "structLibofxFileFormatInfo.html", null ],
-      [ "NodeParser", "classNodeParser.html", null ],
       [ "OFCApplication", "classOFCApplication.html", null ],
       [ "OfxAccountContainer", "classOfxAccountContainer.html", null ],
       [ "OfxAccountData", "structOfxAccountData.html", null ],
@@ -55,30 +54,21 @@ var NAVTREE =
       [ "gengetopt_args_info", "structgengetopt__args__info.html", null ],
       [ "tree< T, tree_node_allocator >::iterator_base", "classtree_1_1iterator__base.html", [
         [ "tree< T, tree_node_allocator >::fixed_depth_iterator", "classtree_1_1fixed__depth__iterator.html", null ],
-        [ "tree< T, tree_node_allocator >::fixed_depth_iterator", "classtree_1_1fixed__depth__iterator.html", null ],
-        [ "tree< T, tree_node_allocator >::post_order_iterator", "classtree_1_1post__order__iterator.html", null ],
         [ "tree< T, tree_node_allocator >::post_order_iterator", "classtree_1_1post__order__iterator.html", null ],
         [ "tree< T, tree_node_allocator >::pre_order_iterator", "classtree_1_1pre__order__iterator.html", null ],
-        [ "tree< T, tree_node_allocator >::pre_order_iterator", "classtree_1_1pre__order__iterator.html", null ],
-        [ "tree< T, tree_node_allocator >::sibling_iterator", "classtree_1_1sibling__iterator.html", null ],
         [ "tree< T, tree_node_allocator >::sibling_iterator", "classtree_1_1sibling__iterator.html", null ]
       ] ],
       [ "tree< T, tree_node_allocator >::iterator_base_less", "classtree_1_1iterator__base__less.html", null ],
       [ "LibofxContext", "classLibofxContext.html", null ],
       [ "LibofxFileFormatInfo", "structLibofxFileFormatInfo.html", null ],
-      [ "NodeParser", "classNodeParser.html", null ],
       [ "OFCApplication", "classOFCApplication.html", null ],
       [ "OfxAccountData", "structOfxAccountData.html", null ],
       [ "OfxAggregate", "classOfxAggregate.html", [
         [ "OfxRequest", "classOfxRequest.html", [
-          [ "OfxAccountInfoRequest", "classOfxAccountInfoRequest.html", null ],
           [ "OfxAccountInfoRequest", "classOfxAccountInfoRequest.html", null ],
           [ "OfxPaymentRequest", "classOfxPaymentRequest.html", null ],
-          [ "OfxPaymentRequest", "classOfxPaymentRequest.html", null ],
-          [ "OfxStatementRequest", "classOfxStatementRequest.html", null ],
           [ "OfxStatementRequest", "classOfxStatementRequest.html", null ]
-        ] ],
-        [ "OfxRequest", "classOfxRequest.html", null ]
+        ] ]
       ] ],
       [ "OFXApplication", "classOFXApplication.html", null ],
       [ "OfxCurrency", "structOfxCurrency.html", null ],
@@ -86,28 +76,17 @@ var NAVTREE =
       [ "OfxFiServiceInfo", "structOfxFiServiceInfo.html", null ],
       [ "OfxGenericContainer", "classOfxGenericContainer.html", [
         [ "OfxAccountContainer", "classOfxAccountContainer.html", null ],
-        [ "OfxAccountContainer", "classOfxAccountContainer.html", null ],
-        [ "OfxBalanceContainer", "classOfxBalanceContainer.html", null ],
         [ "OfxBalanceContainer", "classOfxBalanceContainer.html", null ],
         [ "OfxDummyContainer", "classOfxDummyContainer.html", null ],
-        [ "OfxDummyContainer", "classOfxDummyContainer.html", null ],
-        [ "OfxMainContainer", "classOfxMainContainer.html", null ],
         [ "OfxMainContainer", "classOfxMainContainer.html", null ],
         [ "OfxPushUpContainer", "classOfxPushUpContainer.html", null ],
-        [ "OfxPushUpContainer", "classOfxPushUpContainer.html", null ],
-        [ "OfxSecurityContainer", "classOfxSecurityContainer.html", null ],
         [ "OfxSecurityContainer", "classOfxSecurityContainer.html", null ],
         [ "OfxStatementContainer", "classOfxStatementContainer.html", null ],
-        [ "OfxStatementContainer", "classOfxStatementContainer.html", null ],
-        [ "OfxStatusContainer", "classOfxStatusContainer.html", null ],
         [ "OfxStatusContainer", "classOfxStatusContainer.html", null ],
         [ "OfxTransactionContainer", "classOfxTransactionContainer.html", [
           [ "OfxBankTransactionContainer", "classOfxBankTransactionContainer.html", null ],
-          [ "OfxBankTransactionContainer", "classOfxBankTransactionContainer.html", null ],
-          [ "OfxInvestmentTransactionContainer", "classOfxInvestmentTransactionContainer.html", null ],
           [ "OfxInvestmentTransactionContainer", "classOfxInvestmentTransactionContainer.html", null ]
-        ] ],
-        [ "OfxTransactionContainer", "classOfxTransactionContainer.html", null ]
+        ] ]
       ] ],
       [ "OfxPayee", "structOfxPayee.html", null ],
       [ "OfxPayment", "structOfxPayment.html", null ],
@@ -130,87 +109,43 @@ var NAVTREE =
       [ "ofxdump/cmdline.h", null, null ],
       [ "config.h", null, null ],
       [ "context.cpp", null, null ],
-      [ "fx-0.9.4/lib/context.cpp", null, null ],
       [ "context.hh", null, null ],
-      [ "fx-0.9.4/lib/context.hh", null, null ],
       [ "file_preproc.cpp", "file__preproc_8cpp.html", null ],
-      [ "fx-0.9.4/lib/file_preproc.cpp", "fx-0_89_84_2lib_2file__preproc_8cpp.html", null ],
       [ "file_preproc.hh", "file__preproc_8hh.html", null ],
-      [ "fx-0.9.4/lib/file_preproc.hh", "fx-0_89_84_2lib_2file__preproc_8hh.html", null ],
       [ "getopt.c", null, null ],
-      [ "fx-0.9.4/lib/getopt.c", null, null ],
       [ "getopt1.c", null, null ],
-      [ "fx-0.9.4/lib/getopt1.c", null, null ],
       [ "gnugetopt.h", null, null ],
-      [ "fx-0.9.4/lib/gnugetopt.h", null, null ],
       [ "inc/libofx.h", "inc_2libofx_8h.html", null ],
-      [ "libofx-0.9.4/inc/libofx.h", "libofx-0_89_84_2inc_2libofx_8h.html", null ],
-      [ "main_doc.c", null, null ],
+      [ "libofx-0.9.6/inc/libofx.h", "libofx-0_89_86_2inc_2libofx_8h.html", null ],
       [ "messages.cpp", "messages_8cpp.html", null ],
-      [ "fx-0.9.4/lib/messages.cpp", "fx-0_89_84_2lib_2messages_8cpp.html", null ],
       [ "messages.hh", "messages_8hh.html", null ],
-      [ "fx-0.9.4/lib/messages.hh", "fx-0_89_84_2lib_2messages_8hh.html", null ],
-      [ "nodeparser.cpp", "nodeparser_8cpp.html", null ],
-      [ "nodeparser.h", "nodeparser_8h.html", null ],
       [ "ofc_sgml.cpp", "ofc__sgml_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofc_sgml.cpp", "fx-0_89_84_2lib_2ofc__sgml_8cpp.html", null ],
       [ "ofc_sgml.hh", "ofc__sgml_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofc_sgml.hh", "fx-0_89_84_2lib_2ofc__sgml_8hh.html", null ],
-      [ "ofx2qif.c", "ofx2qif_8c.html", null ],
       [ "ofx_aggregate.hh", "ofx__aggregate_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_aggregate.hh", "fx-0_89_84_2lib_2ofx__aggregate_8hh.html", null ],
       [ "ofx_container_account.cpp", "ofx__container__account_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_container_account.cpp", "fx-0_89_84_2lib_2ofx__container__account_8cpp.html", null ],
       [ "ofx_container_generic.cpp", "ofx__container__generic_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_container_generic.cpp", "fx-0_89_84_2lib_2ofx__container__generic_8cpp.html", null ],
       [ "ofx_container_main.cpp", "ofx__container__main_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_container_main.cpp", "fx-0_89_84_2lib_2ofx__container__main_8cpp.html", null ],
       [ "ofx_container_security.cpp", "ofx__container__security_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_container_security.cpp", "fx-0_89_84_2lib_2ofx__container__security_8cpp.html", null ],
       [ "ofx_container_statement.cpp", "ofx__container__statement_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_container_statement.cpp", "fx-0_89_84_2lib_2ofx__container__statement_8cpp.html", null ],
       [ "ofx_container_transaction.cpp", "ofx__container__transaction_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_container_transaction.cpp", "fx-0_89_84_2lib_2ofx__container__transaction_8cpp.html", null ],
       [ "ofx_containers.hh", "ofx__containers_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_containers.hh", "fx-0_89_84_2lib_2ofx__containers_8hh.html", null ],
       [ "ofx_containers_misc.cpp", "ofx__containers__misc_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_containers_misc.cpp", "fx-0_89_84_2lib_2ofx__containers__misc_8cpp.html", null ],
       [ "ofx_error_msg.hh", "ofx__error__msg_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_error_msg.hh", "fx-0_89_84_2lib_2ofx__error__msg_8hh.html", null ],
       [ "ofx_preproc.cpp", "ofx__preproc_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_preproc.cpp", "fx-0_89_84_2lib_2ofx__preproc_8cpp.html", null ],
       [ "ofx_preproc.hh", "ofx__preproc_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_preproc.hh", "fx-0_89_84_2lib_2ofx__preproc_8hh.html", null ],
       [ "ofx_request.cpp", "ofx__request_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_request.cpp", "fx-0_89_84_2lib_2ofx__request_8cpp.html", null ],
       [ "ofx_request.hh", "ofx__request_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_request.hh", "fx-0_89_84_2lib_2ofx__request_8hh.html", null ],
       [ "ofx_request_accountinfo.cpp", "ofx__request__accountinfo_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_request_accountinfo.cpp", "fx-0_89_84_2lib_2ofx__request__accountinfo_8cpp.html", null ],
       [ "ofx_request_accountinfo.hh", "ofx__request__accountinfo_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_request_accountinfo.hh", "fx-0_89_84_2lib_2ofx__request__accountinfo_8hh.html", null ],
       [ "ofx_request_statement.cpp", "ofx__request__statement_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_request_statement.cpp", "fx-0_89_84_2lib_2ofx__request__statement_8cpp.html", null ],
       [ "ofx_request_statement.hh", "ofx__request__statement_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_request_statement.hh", "fx-0_89_84_2lib_2ofx__request__statement_8hh.html", null ],
       [ "ofx_sgml.cpp", "ofx__sgml_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_sgml.cpp", "fx-0_89_84_2lib_2ofx__sgml_8cpp.html", null ],
       [ "ofx_sgml.hh", "ofx__sgml_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_sgml.hh", "fx-0_89_84_2lib_2ofx__sgml_8hh.html", null ],
       [ "ofx_utilities.cpp", "ofx__utilities_8cpp.html", null ],
-      [ "fx-0.9.4/lib/ofx_utilities.cpp", "fx-0_89_84_2lib_2ofx__utilities_8cpp.html", null ],
       [ "ofx_utilities.hh", "ofx__utilities_8hh.html", null ],
-      [ "fx-0.9.4/lib/ofx_utilities.hh", "fx-0_89_84_2lib_2ofx__utilities_8hh.html", null ],
-      [ "ofxconnect.cpp", "ofxconnect_8cpp.html", null ],
-      [ "ofxdump.cpp", "ofxdump_8cpp.html", null ],
-      [ "ofxpartner.cpp", "ofxpartner_8cpp.html", null ],
-      [ "ofxpartner.h", "ofxpartner_8h.html", null ],
       [ "tree.hh", null, null ],
-      [ "fx-0.9.4/lib/tree.hh", null, null ],
       [ "win32.cpp", null, null ],
-      [ "fx-0.9.4/lib/win32.cpp", null, null ],
-      [ "win32.hh", null, null ],
-      [ "fx-0.9.4/lib/win32.hh", null, null ]
+      [ "win32.hh", null, null ]
     ] ],
     [ "Globals", "globals.html", null ]
   ] ]
